summaryrefslogtreecommitdiffstats
path: root/keyboards/planck
diff options
context:
space:
mode:
authorAlbert Y <76888457+filterpaper@users.noreply.github.com>2022-12-12 23:52:22 +0800
committerGitHub <noreply@github.com>2022-12-12 16:52:22 +0100
commitcbabc8dbe6a8476d3082e8bc649d330f87e7b904 (patch)
tree55e73275367047981295d046867d9f70352814c7 /keyboards/planck
parent8698d109d7c2f4554e0f3c01b017738a0a47f162 (diff)
[Core] Replace Tapping Force Hold feature with Quick Tap Term (#17007)
* Replace Tapping Force Hold feature with Quick Tap Term * Replace keyboard level TAPPING_FORCE_HOLD with QUICK_TAP_TERM 0 * Deprecate force hold in info_config.json * Before and after quick tap term unit tests * Quick tap unit tests iteration * Keymap config.h correction * Remove TAPPING_FORCE_HOLD_PER_KEY macros that were missed * Add two more test cases for quick tap * Replace TAPPING_FORCE_HOLD with QUICK_TAP_TERM in configs #2 * Replace TAPPING_FORCE_HOLD_PER_KEY with QUICK_TAP_TERM_PER_KEY in configs #2 * Add function declaration for get_quick_tap_term Co-authored-by: Stefan Kerkmann <karlk90@pm.me>
Diffstat (limited to 'keyboards/planck')
-rw-r--r--keyboards/planck/keymaps/adamtabrams/config.h4
-rw-r--r--keyboards/planck/keymaps/adamtabrams/keymap.c6
-rw-r--r--keyboards/planck/keymaps/jweickm/config.h2
-rw-r--r--keyboards/planck/keymaps/jweickm/keymap.c24
-rw-r--r--keyboards/planck/keymaps/muppetjones/config.h2
-rw-r--r--keyboards/planck/keymaps/rootiest/config.h2
-rw-r--r--keyboards/planck/keymaps/rootiest/keymap.c6
-rw-r--r--keyboards/planck/keymaps/tylerwince/config.h2
8 files changed, 24 insertions, 24 deletions
diff --git a/keyboards/planck/keymaps/adamtabrams/config.h b/keyboards/planck/keymaps/adamtabrams/config.h
index 0c275f20c5..8ff86760b4 100644
--- a/keyboards/planck/keymaps/adamtabrams/config.h
+++ b/keyboards/planck/keymaps/adamtabrams/config.h
@@ -35,5 +35,5 @@
#define PERMISSIVE_HOLD
#define IGNORE_MOD_TAP_INTERRUPT
#define IGNORE_MOD_TAP_INTERRUPT_PER_KEY
-#define TAPPING_FORCE_HOLD
-#define TAPPING_FORCE_HOLD_PER_KEY
+#define QUICK_TAP_TERM 0
+#define QUICK_TAP_TERM_PER_KEY
diff --git a/keyboards/planck/keymaps/adamtabrams/keymap.c b/keyboards/planck/keymaps/adamtabrams/keymap.c
index 3d4aa46963..2203ecd30f 100644
--- a/keyboards/planck/keymaps/adamtabrams/keymap.c
+++ b/keyboards/planck/keymaps/adamtabrams/keymap.c
@@ -229,7 +229,7 @@ bool process_record_user(uint16_t keycode, keyrecord_t *record) {
return true;
}
-bool get_tapping_force_hold(uint16_t keycode, keyrecord_t *record) {
+uint16_t get_quick_tap_term(uint16_t keycode, keyrecord_t *record) {
switch (keycode) {
case SHFTESC:
case NUMSPAC:
@@ -249,9 +249,9 @@ bool get_tapping_force_hold(uint16_t keycode, keyrecord_t *record) {
case CTL__J:
case CTL__T:
case CTL__N:
- return true;
+ return 0;
default:
- return false;
+ return QUICK_TAP_TERM;
}
}
diff --git a/keyboards/planck/keymaps/jweickm/config.h b/keyboards/planck/keymaps/jweickm/config.h
index 3b34ddf832..bd34fca202 100644
--- a/keyboards/planck/keymaps/jweickm/config.h
+++ b/keyboards/planck/keymaps/jweickm/config.h
@@ -58,7 +58,7 @@
#define TAPPING_TERM_PER_KEY
//#define PERMISSIVE_HOLD
#define IGNORE_MOD_TAP_INTERRUPT
-#define TAPPING_FORCE_HOLD_PER_KEY
+#define QUICK_TAP_TERM_PER_KEY
// settings for LEADER key
#define LEADER_PER_KEY_TIMING
diff --git a/keyboards/planck/keymaps/jweickm/keymap.c b/keyboards/planck/keymaps/jweickm/keymap.c
index b2c317f039..1b8b8b28a8 100644
--- a/keyboards/planck/keymaps/jweickm/keymap.c
+++ b/keyboards/planck/keymaps/jweickm/keymap.c
@@ -1039,30 +1039,30 @@ bool music_mask_user(uint16_t keycode) {
}
}
-bool get_tapping_force_hold(uint16_t keycode, keyrecord_t *record) {
+uint16_t get_quick_tap_term(uint16_t keycode, keyrecord_t *record) {
switch (keycode) {
case LSFT_T(KC_S):
- return true;
+ return 0;
case RSFT_T(KC_E):
- return true;
+ return 0;
case LSFT_T(KC_D):
- return true;
+ return 0;
case RSFT_T(KC_K):
- return true;
+ return 0;
case LSFT_T(KC_F):
- return true;
+ return 0;
case RSFT_T(KC_U):
- return true;
+ return 0;
case LT(_RAISE, KC_ENT):
- return true;
+ return 0;
case LT(_RAISE_DE, KC_ENT):
- return true;
+ return 0;
case LT(_LOWER, KC_BSPC):
- return true;
+ return 0;
case LT(_LOWER_DE, KC_BSPC):
- return true;
+ return 0;
default:
- return false;
+ return QUICK_TAP_TERM;
}
}
diff --git a/keyboards/planck/keymaps/muppetjones/config.h b/keyboards/planck/keymaps/muppetjones/config.h
index 1046d21499..1a05bfc837 100644
--- a/keyboards/planck/keymaps/muppetjones/config.h
+++ b/keyboards/planck/keymaps/muppetjones/config.h
@@ -53,4 +53,4 @@
#define IGNORE_MOD_TAP_INTERRUPT
// Enable rapid switch from tap to hold, disables double tap hold auto-repeat.
-#define TAPPING_FORCE_HOLD
+#define QUICK_TAP_TERM 0
diff --git a/keyboards/planck/keymaps/rootiest/config.h b/keyboards/planck/keymaps/rootiest/config.h
index 4de638ce29..bdb5cea91b 100644
--- a/keyboards/planck/keymaps/rootiest/config.h
+++ b/keyboards/planck/keymaps/rootiest/config.h
@@ -117,7 +117,7 @@
* MACRO per-key options
*/
#define RETRO_TAPPING_PER_KEY // Control Retro-Tap individually by key
-#define TAPPING_FORCE_HOLD_PER_KEY // Control Force-Hold individually by key
+#define QUICK_TAP_TERM_PER_KEY // Control Quick-Tap individually by key
#define IGNORE_MOD_TAP_INTERRUPT_PER_KEY // Control Mod-Tap-Interrupt individually by key
#define PERMISSIVE_HOLD_PER_KEY // Control Permissive-Hold individually by key
diff --git a/keyboards/planck/keymaps/tylerwince/config.h b/keyboards/planck/keymaps/tylerwince/config.h
index 24adad94f3..52c1494a1d 100644
--- a/keyboards/planck/keymaps/tylerwince/config.h
+++ b/keyboards/planck/keymaps/tylerwince/config.h
@@ -12,7 +12,7 @@
Set any config.h overrides for your specific keymap here.
See config.h options at https://docs.qmk.fm/#/config_options?id=the-configh-file
*/
-#define TAPPING_FORCE_HOLD
+#define QUICK_TAP_TERM 0
#define IGNORE_MOD_TAP_INTERRUPT
#define EECONFIG_RGB_MATRIX (uint32_t *)16
diff --git a/keyboards/planck/keymaps/rootiest/keymap.c b/keyboards/planck/keymaps/rootiest/keymap.c
index 097f313cca..cc43aff673 100644
--- a/keyboards/planck/keymaps/rootiest/keymap.c
+++ b/keyboards/planck/keymaps/rootiest/keymap.c
@@ -1376,11 +1376,11 @@ bool get_ignore_mod_tap_interrupt(uint16_t keycode, keyrecord_t* record) {
return false;
}
}
-// Handles per-key configuration of Tapping Force-Hold
-bool get_tapping_force_hold(uint16_t keycode, keyrecord_t* record) {
+// Handles per-key configuration of Quick-Tap
+uint16_t get_quick_tap_term(uint16_t keycode, keyrecord_t* record) {
switch (keycode) {
default:
- return false;
+ return QUICK_TAP_TERM;
}
}
// Handles per-key configuration of Permissive-Hold